==> ocg_app-0.0.38.tar.gz: lib/src/screens/onboarding.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:smooth_page_indicator/smooth_page_indicator.dart';

class OnboardingScreen extends StatefulWidget {
  final List<OnboardingItem> items;
  final Function() onSkip;
  final bool canGoBack;
  OnboardingScreen(
      {Key key,
      @required this.items,
      @required this.onSkip,
      this.canGoBack = false})
      : super(key: key);

  @override
  _OnboardingScreenState createState() => _OnboardingScreenState();
}

class _OnboardingScreenState extends State<OnboardingScreen> {
  PageController _pageController;

  @override
  void initState() {
    super.initState();
    _pageController = PageController(
      initialPage: 0,
    );
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        return widget.canGoBack;
      },
      child: Scaffold(
        backgroundColor: Colors.transparent,
        body: Padding(
          padding: const EdgeInsets.symmetric(vertical: 18, horizontal: 24),
          child: Column(
            children: [
              Expanded(
                child: PageView.builder(
                  itemBuilder: (context, index) {
                    OnboardingItem item = items[index];
                    return OnboardingPage(
                      item: item,
                    );
                  },
                  controller: _pageController,
                  itemCount: items.length,
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height * 0.035,
              ),
              Row(
                children: [
                  SmoothPageIndicator(
                      controller: _pageController, // PageController
                      count: items.length,
                      effect: WormEffect(
                          dotColor: Color(0xffeeeeee),
                          radius: 12,
                          dotWidth: 12,
                          dotHeight: 12), // your preferred effect
                      onDotClicked: (index) {
                        _pageController.animateToPage(index,
                            duration: Duration(milliseconds: 200),
                            curve: Curves.easeIn);
                      }),
                  Spacer(),
                  CupertinoButton(
                      child: Text(
                        "Skip",
                        style: TextStyle(fontWeight: FontWeight.w600),
                      ),
                      onPressed: widget.onSkip)
                ],
              )
            ],
          ),
        ),
      ),
    );
  }

  List<OnboardingItem> get items => widget.items;
}

class OnboardingPage extends StatelessWidget {
  final OnboardingItem item;
  const OnboardingPage({Key key, this.item}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.stretch,
      children: [
        Expanded(child: SvgPicture.asset("${item.image}")),
        SizedBox(
          height: 2,
        ),
        Text(
          "${item.title}",
          maxLines: 2,
          overflow: TextOverflow.ellipsis,
          style: TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
        ),
        SizedBox(
          height: 6,
        ),
        Text(
          "${item.description}",
          maxLines: 2,
          overflow: TextOverflow.ellipsis,
          style: TextStyle(
            fontSize: 14.5,
          ),
        ),
      ],
    );
  }
}

class OnboardingItem {
  final String title;
  final String description;
  final String image;

  OnboardingItem(this.title, this.description, this.image);

  OnboardingItem.named({this.title, this.description, this.image});
}

==> ocg_app-0.0.52.tar.gz: lib/src/screens/onboarding.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:smooth_page_indicator/smooth_page_indicator.dart';

class OnboardingScreen extends StatefulWidget {
  final List<OnboardingItem> items;
  final Function() onSkip;
  final bool canGoBack;
  OnboardingScreen(
      {Key key,
      @required this.items,
      @required this.onSkip,
      this.canGoBack = false})
      : super(key: key);

  @override
  _OnboardingScreenState createState() => _OnboardingScreenState();
}

class _OnboardingScreenState extends State<OnboardingScreen> {
  PageController _pageController;

  @override
  void initState() {
    super.initState();
    _pageController = PageController(
      initialPage: 0,
    );
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        return widget.canGoBack;
      },
      child: Scaffold(
        backgroundColor: Colors.transparent,
        body: Padding(
          padding: const EdgeInsets.symmetric(vertical: 18, horizontal: 24),
          child: Column(
            children: [
              Expanded(
                child: PageView.builder(
                  itemBuilder: (context, index) {
                    OnboardingItem item = items[index];
                    return OnboardingPage(
                      item: item,
                    );
                  },
                  controller: _pageController,
                  itemCount: items.length,
                ),
              ),
              SizedBox(
                height: MediaQuery.of(context).size.height * 0.035,
              ),
              Row(
                children: [
                  SmoothPageIndicator(
                      controller: _pageController, // PageController
                      count: items.length,
                      effect: WormEffect(
                          dotColor: Color(0xffeeeeee),
                          radius: 12,
                          dotWidth: 12,
                          dotHeight: 12), // your preferred effect
                      onDotClicked: (index) {
                        _pageController.animateToPage(index,
                            duration: Duration(milliseconds: 200),
                            curve: Curves.easeIn);
                      }),
                  Spacer(),
                  CupertinoButton(
                      child: Text(
                        "Skip",
                        style: TextStyle(fontWeight: FontWeight.w600),
                      ),
                      onPressed: widget.onSkip)
                ],
              )
            ],
          ),
        ),
      ),
    );
  }

  List<OnboardingItem> get items => widget.items;
}

class OnboardingPage extends StatelessWidget {
  final OnboardingItem item;
  const OnboardingPage({Key key, this.item}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.stretch,
      children: [
        Expanded(child: Image.asset("${item.image}")),
        SizedBox(
          height: 2,
        ),
        Text(
          "${item.title}",
          maxLines: 2,
          overflow: TextOverflow.ellipsis,
          style: TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
        ),
        SizedBox(
          height: 6,
        ),
        Text(
          "${item.description}",
          maxLines: 2,
          overflow: TextOverflow.ellipsis,
          style: TextStyle(
            fontSize: 14.5,
          ),
        ),
      ],
    );
  }
}

class OnboardingItem {
  final String title;
  final String description;
  final String image;

  OnboardingItem(this.title, this.description, this.image);

  OnboardingItem.named({this.title, this.description, this.image});
}
